<!-- DO NOT EDIT: this file is automatically generated using scw-doc-gen -->
# Documentation for `scw iot`
This API allows you to manage IoT hubs and devices
  
- [IoT Device commands](#iot-device-commands)
  - [Add a device](#add-a-device)
  - [Remove a device](#remove-a-device)
  - [Disable a device](#disable-a-device)
  - [Enable a device](#enable-a-device)
  - [Get a device](#get-a-device)
  - [Get a device's metrics](#get-a-device's-metrics)
  - [List devices](#list-devices)
  - [Update a device](#update-a-device)
- [IoT Hub commands](#iot-hub-commands)
  - [Create a hub](#create-a-hub)
  - [Delete a hub](#delete-a-hub)
  - [Disable a hub](#disable-a-hub)
  - [Enable a hub](#enable-a-hub)
  - [Get a hub](#get-a-hub)
  - [List hubs](#list-hubs)
  - [Update a hub](#update-a-hub)
- [IoT Network commands](#iot-network-commands)
  - [Create a new Network](#create-a-new-network)
  - [Delete a Network](#delete-a-network)
  - [Retrieve a specific Network](#retrieve-a-specific-network)
  - [List the Networks](#list-the-networks)
- [IoT Route commands](#iot-route-commands)

  
## IoT Device commands

IoT Device commands.


### Add a device

Add a device.

**Usage:**

```
scw iot device create [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| name | Required<br />Default: `<generated>` | Device name |
| hub-id | Required | ID of the device's hub |
| allow-insecure |  | Allow plain and server-authenticated SSL connections in addition to mutually-authenticated ones |
| message-filters.publish.policy | One of: `unknown`, `accept`, `reject` |  |
| message-filters.publish.topics.{index} |  |  |
| message-filters.subscribe.policy | One of: `unknown`, `accept`, `reject` |  |
| message-filters.subscribe.topics.{index} |  |  |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Remove a device

Remove a device.

**Usage:**

```
scw iot device delete <device-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| device-id | Required | Device ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Disable a device

Disable a device.

**Usage:**

```
scw iot device disable <device-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| device-id | Required | Device ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Enable a device

Enable a device.

**Usage:**

```
scw iot device enable <device-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| device-id | Required | Device ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Get a device

Get a device.

**Usage:**

```
scw iot device get <device-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| device-id | Required | Device ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Get a device's metrics

Get a device's metrics.

**Usage:**

```
scw iot device get-metrics <device-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| device-id | Required | Device ID |
| period | Required<br />Default: `hour`<br />One of: `hour`, `day`, `week`, `month`, `year` | Period over which the metrics span |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### List devices

List devices.

**Usage:**

```
scw iot device list [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| order-by | One of: `name_asc`, `name_desc`, `status_asc`, `status_desc`, `hub_id_asc`, `hub_id_desc`, `created_at_asc`, `created_at_desc`, `updated_at_asc`, `updated_at_desc`, `allow_insecure_asc`, `allow_insecure_desc` | Ordering of requested devices |
| name |  | Filter on the name |
| hub-id |  | Filter on the hub |
| enabled |  | Deprecated, ignored filter |
| allow-insecure |  | Filter on the allow_insecure flag |
| is-connected |  | Deprecated, ignored filter |
| organization-id |  | Filter on the organization |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Update a device

Update a device.

**Usage:**

```
scw iot device update <device-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| device-id | Required | Device ID |
| name |  | Device name |
| allow-insecure |  | Allow plain and server-authenticated SSL connections in addition to mutually-authenticated ones |
| message-filters.publish.policy | One of: `unknown`, `accept`, `reject` |  |
| message-filters.publish.topics.{index} |  |  |
| message-filters.subscribe.policy | One of: `unknown`, `accept`, `reject` |  |
| message-filters.subscribe.topics.{index} |  |  |
| hub-id |  | Change Hub for this device, additional fees may apply, see IoT Hub pricing |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



## IoT Hub commands

IoT Hub commands.


### Create a hub

Create a hub.

**Usage:**

```
scw iot hub create [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| name | Required<br />Default: `<generated>` | Hub name (up to 255 characters) |
| product-plan | Required<br />Default: `plan_shared`<br />One of: `plan_unknown`, `plan_shared`, `plan_dedicated`, `plan_ha` | Hub feature set |
| disable-events |  | Disable Hub events (default false) |
| events-topic-prefix |  | Hub events topic prefix (default '$SCW/events') |
| organization-id |  | Organization ID to use. If none is passed the default organization ID will be used |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Delete a hub

Delete a hub.

**Usage:**

```
scw iot hub delete <hub-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| hub-id | Required | Hub ID |
| delete-devices |  | Force deletion of devices added to this hub instead of rejecting operation |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Disable a hub

Disable a hub.

**Usage:**

```
scw iot hub disable <hub-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| hub-id | Required | Hub ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Enable a hub

Enable a hub.

**Usage:**

```
scw iot hub enable <hub-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| hub-id | Required | Hub ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Get a hub

Get a hub.

**Usage:**

```
scw iot hub get <hub-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| hub-id | Required | Hub ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### List hubs

List hubs.

**Usage:**

```
scw iot hub list [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| order-by | One of: `name_asc`, `name_desc`, `status_asc`, `status_desc`, `product_plan_asc`, `product_plan_desc`, `created_at_asc`, `created_at_desc`, `updated_at_asc`, `updated_at_desc` | Ordering of requested hub |
| name |  | Filter on the name |
| organization-id |  | Filter on the organization |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Update a hub

Update a hub.

**Usage:**

```
scw iot hub update <hub-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| hub-id | Required | Hub ID |
| name |  | Hub name (up to 255 characters) |
| product-plan | One of: `plan_unknown`, `plan_shared`, `plan_dedicated`, `plan_ha` | Hub feature set |
| disable-events |  | Disable Hub events |
| events-topic-prefix |  | Hub events topic prefix |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



## IoT Network commands

IoT Network commands.


### Create a new Network

Create a new Network.

**Usage:**

```
scw iot network create [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| name | Required<br />Default: `<generated>` | Network name |
| type | Required<br />One of: `unknown`, `sigfox`, `rest` | Type of network to connect with |
| hub-id | Required | Hub ID to connect the Network to |
| topic-prefix | Required | Topic prefix for the Network |
| organization-id |  | Organization ID to use. If none is passed the default organization ID will be used |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Delete a Network

Delete a Network.

**Usage:**

```
scw iot network delete <network-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| network-id | Required | Network ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### Retrieve a specific Network

Retrieve a specific Network.

**Usage:**

```
scw iot network get <network-id ...> [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| network-id | Required | Network ID |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



### List the Networks

List the Networks.

**Usage:**

```
scw iot network list [arg=value ...]
```


**Args:**

| Name |   | Description |
|------|---|-------------|
| order-by | One of: `name_asc`, `name_desc`, `type_asc`, `type_desc`, `created_at_asc`, `created_at_desc` | Ordering of requested routes |
| name |  | Filter on Network name |
| hub-id |  | Filter on the hub |
| topic-prefix |  | Filter on the topic prefix |
| organization-id |  | Filter on the organization |
| region | Default: `fr-par`<br />One of: `fr-par` | Region to target. If none is passed will use default region from the config |



## IoT Route commands

IoT Route commands.

IoT Route commands.

**Usage:**

```
scw iot route
```



